@@ -177,8 +177,7 @@ static gchar *
 digest_to_string (guint8 *digest,
                   gsize   digest_len)
 {
-  gint len = digest_len * 2;
-  gint i;
+  gsize i, len = digest_len * 2;
   gchar *retval;
 
   retval = g_new (gchar, len + 1);
@@ -463,7 +462,7 @@ md5_sum_digest (Md5sum *md5,
 
 /* The following implementation comes from D-Bus dbus-sha.c. I've changed
  * it to use GLib types and to work more like the MD5 implementation above.
- * I left the comments to have an history of this code.
+ * I left the comments to have a history of this code.
  *      -- Emmanuele Bassi, ebassi@gnome.org
  */
 
@@ -1629,7 +1628,7 @@ g_checksum_update (GChecksum    *checksum,
  * g_checksum_get_string:
  * @checksum: a #GChecksum
  *
- * Gets the digest as an hexadecimal string.
+ * Gets the digest as a hexadecimal string.
  *
  * Once this function has been called the #GChecksum can no longer be
  * updated with g_checksum_update().
