@@ -138,7 +138,7 @@
 #define G_DATALIST_FLAGS_MASK_INTERNAL 0x7
 
 /* datalist pointer accesses have to be carried out atomically */
-#define G_DATALIST_GET_POINTER(datalist)                        \
+#define G_DATALIST_GET_POINTER(datalist)            \
   ((GData*) ((gsize) g_atomic_pointer_get (datalist) & ~(gsize) G_DATALIST_FLAGS_MASK_INTERNAL))
 
 #define G_DATALIST_SET_POINTER(datalist, pointer)       G_STMT_START {                  \
@@ -172,15 +172,15 @@ struct _GDataset
 
 
 /* --- prototypes --- */
-static inline GDataset* g_dataset_lookup        (gconstpointer    dataset_location);
-static inline void  g_datalist_clear_i      (GData      **datalist);
-static void     g_dataset_destroy_internal  (GDataset    *dataset);
-static inline gpointer  g_data_set_internal     (GData      **datalist,
-                             GQuark       key_id,
-                             gpointer         data,
-                             GDestroyNotify   destroy_func,
-                             GDataset    *dataset);
-static void     g_data_initialize       (void);
+static inline GDataset* g_dataset_lookup    (gconstpointer    dataset_location);
+static inline void  g_datalist_clear_i    (GData    **datalist);
+static void   g_dataset_destroy_internal  (GDataset  *dataset);
+static inline gpointer  g_data_set_internal   (GData      **datalist,
+               GQuark       key_id,
+               gpointer         data,
+               GDestroyNotify   destroy_func,
+               GDataset  *dataset);
+static void   g_data_initialize   (void);
 
 /* Locking model:
  * Each standalone GDataList is protected by a bitlock in the datalist pointer,
@@ -197,7 +197,7 @@ static void     g_data_initialize       (void);
 G_LOCK_DEFINE_STATIC (g_dataset_global);
 static GHashTable   *g_dataset_location_ht = NULL;
 static GDataset     *g_dataset_cached = NULL; /* should this be
-                         thread specific? */
+             thread specific? */
 
 /* --- functions --- */
 
@@ -222,7 +222,7 @@ static void
 g_datalist_clear_i (GData **datalist)
 {
   GData *data;
-  gint i;
+  guint i;
 
   data = G_DATALIST_GET_POINTER (datalist);
   G_DATALIST_SET_POINTER (datalist, NULL);
@@ -254,7 +254,7 @@ void
 g_datalist_clear (GData **datalist)
 {
   GData *data;
-  gint i;
+  guint i;
 
   g_return_if_fail (datalist != NULL);
 
@@ -303,13 +303,13 @@ g_dataset_destroy_internal (GDataset *dataset)
   while (dataset)
     {
       if (G_DATALIST_GET_POINTER(&dataset->datalist) == NULL)
-    {
-      if (dataset == g_dataset_cached)
-        g_dataset_cached = NULL;
-      g_hash_table_remove (g_dataset_location_ht, dataset_location);
-      g_slice_free (GDataset, dataset);
-      break;
-    }
+  {
+    if (dataset == g_dataset_cached)
+      g_dataset_cached = NULL;
+    g_hash_table_remove (g_dataset_location_ht, dataset_location);
+    g_slice_free (GDataset, dataset);
+    break;
+  }
 
       g_datalist_clear_i (&dataset->datalist);
       dataset = g_dataset_lookup (dataset_location);
@@ -335,7 +335,7 @@ g_dataset_destroy (gconstpointer  dataset_location)
 
       dataset = g_dataset_lookup (dataset_location);
       if (dataset)
-    g_dataset_destroy_internal (dataset);
+  g_dataset_destroy_internal (dataset);
     }
   G_UNLOCK (g_dataset_global);
 }
@@ -343,10 +343,10 @@ g_dataset_destroy (gconstpointer  dataset_location)
 /* HOLDS: g_dataset_global_lock if dataset != null */
 static inline gpointer
 g_data_set_internal (GData    **datalist,
-                     GQuark         key_id,
-                     gpointer       new_data,
-                     GDestroyNotify new_destroy_func,
-             GDataset      *dataset)
+         GQuark         key_id,
+         gpointer       new_data,
+         GDestroyNotify new_destroy_func,
+         GDataset    *dataset)
 {
   GData *d, *old_d;
   GDataElt old, *data, *data_last, *data_end;
@@ -358,120 +358,120 @@ g_data_set_internal (GData    **datalist,
   if (new_data == NULL) /* remove */
     {
       if (d)
+  {
+    data = d->data;
+    data_last = data + d->len - 1;
+    while (data <= data_last)
+      {
+        if (data->key == key_id)
     {
-      data = d->data;
-      data_last = data + d->len - 1;
-      while (data <= data_last)
-        {
-          if (data->key == key_id)
-        {
-          old = *data;
-          if (data != data_last)
-            *data = *data_last;
-          d->len--;
+      old = *data;
+      if (data != data_last)
+        *data = *data_last;
+      d->len--;
 
-          /* We don't bother to shrink, but if all data are now gone
-           * we at least free the memory
+      /* We don't bother to shrink, but if all data are now gone
+       * we at least free the memory
                    */
-          if (d->len == 0)
-            {
-              G_DATALIST_SET_POINTER (datalist, NULL);
-              g_free (d);
-              /* datalist may be situated in dataset, so must not be
-               * unlocked after we free it
-               */
-              g_datalist_unlock (datalist);
-
-              /* the dataset destruction *must* be done
-               * prior to invocation of the data destroy function
-               */
-              if (dataset)
-            g_dataset_destroy_internal (dataset);
-            }
-          else
-            {
-              g_datalist_unlock (datalist);
-            }
-
-          /* We found and removed an old value
-           * the GData struct *must* already be unlinked
-           * when invoking the destroy function.
-           * we use (new_data==NULL && new_destroy_func!=NULL) as
-           * a special hint combination to "steal"
-           * data without destroy notification
+      if (d->len == 0)
+        {
+          G_DATALIST_SET_POINTER (datalist, NULL);
+          g_free (d);
+          /* datalist may be situated in dataset, so must not be
+           * unlocked after we free it
            */
-          if (old.destroy && !new_destroy_func)
-            {
-              if (dataset)
-            G_UNLOCK (g_dataset_global);
-              old.destroy (old.data);
-              if (dataset)
-            G_LOCK (g_dataset_global);
-              old.data = NULL;
-            }
+          g_datalist_unlock (datalist);
 
-          return old.data;
+          /* the dataset destruction *must* be done
+           * prior to invocation of the data destroy function
+           */
+          if (dataset)
+      g_dataset_destroy_internal (dataset);
         }
-          data++;
+      else
+        {
+          g_datalist_unlock (datalist);
         }
+
+      /* We found and removed an old value
+       * the GData struct *must* already be unlinked
+       * when invoking the destroy function.
+       * we use (new_data==NULL && new_destroy_func!=NULL) as
+       * a special hint combination to "steal"
+       * data without destroy notification
+       */
+      if (old.destroy && !new_destroy_func)
+        {
+          if (dataset)
+      G_UNLOCK (g_dataset_global);
+          old.destroy (old.data);
+          if (dataset)
+      G_LOCK (g_dataset_global);
+          old.data = NULL;
+        }
+
+      return old.data;
     }
+        data++;
+      }
+  }
     }
   else
     {
       old.data = NULL;
       if (d)
+  {
+    data = d->data;
+    data_end = data + d->len;
+    while (data < data_end)
+      {
+        if (data->key == key_id)
     {
-      data = d->data;
-      data_end = data + d->len;
-      while (data < data_end)
+      if (!data->destroy)
         {
-          if (data->key == key_id)
+          data->data = new_data;
+          data->destroy = new_destroy_func;
+          g_datalist_unlock (datalist);
+        }
+      else
         {
-          if (!data->destroy)
-            {
-              data->data = new_data;
-              data->destroy = new_destroy_func;
-              g_datalist_unlock (datalist);
-            }
-          else
-            {
-              old = *data;
-              data->data = new_data;
-              data->destroy = new_destroy_func;
+          old = *data;
+          data->data = new_data;
+          data->destroy = new_destroy_func;
 
-              g_datalist_unlock (datalist);
+          g_datalist_unlock (datalist);
 
-              /* We found and replaced an old value
-               * the GData struct *must* already be unlinked
-               * when invoking the destroy function.
-               */
-              if (dataset)
-            G_UNLOCK (g_dataset_global);
-              old.destroy (old.data);
-              if (dataset)
-            G_LOCK (g_dataset_global);
-            }
-          return NULL;
-        }
-          data++;
+          /* We found and replaced an old value
+           * the GData struct *must* already be unlinked
+           * when invoking the destroy function.
+           */
+          if (dataset)
+      G_UNLOCK (g_dataset_global);
+          old.destroy (old.data);
+          if (dataset)
+      G_LOCK (g_dataset_global);
         }
+      return NULL;
     }
+        data++;
+      }
+  }
 
       /* The key was not found, insert it */
       old_d = d;
       if (d == NULL)
-    {
-      d = g_malloc (sizeof (GData));
-      d->len = 0;
-      d->alloc = 1;
-    }
+  {
+    d = g_malloc (sizeof (GData));
+    d->len = 0;
+    d->alloc = 1;
+  }
       else if (d->len == d->alloc)
-    {
-      d->alloc = d->alloc * 2;
-      d = g_realloc (d, sizeof (GData) + (d->alloc - 1) * sizeof (GDataElt));
-    }
+  {
+    d->alloc = d->alloc * 2;
+    d = g_realloc (d, sizeof (GData) + (d->alloc - 1) * sizeof (GDataElt));
+  }
       if (old_d != d)
-    G_DATALIST_SET_POINTER (datalist, d);
+  G_DATALIST_SET_POINTER (datalist, d);
 
       d->data[d->len].key = key_id;
       d->data[d->len].data = new_data;
@@ -548,9 +548,9 @@ g_data_set_internal (GData    **datalist,
  **/
 void
 g_dataset_id_set_data_full (gconstpointer  dataset_location,
-                GQuark         key_id,
-                gpointer       data,
-                GDestroyNotify destroy_func)
+          GQuark         key_id,
+          gpointer       data,
+          GDestroyNotify destroy_func)
 {
   GDataset *dataset;
 
@@ -560,9 +560,9 @@ g_dataset_id_set_data_full (gconstpointer  dataset_location,
   if (!key_id)
     {
       if (data)
-    g_return_if_fail (key_id > 0);
+  g_return_if_fail (key_id > 0);
       else
-    return;
+  return;
     }
 
   G_LOCK (g_dataset_global);
@@ -582,8 +582,8 @@ g_dataset_id_set_data_full (gconstpointer  dataset_location,
       dataset->location = dataset_location;
       g_datalist_init (&dataset->datalist);
       g_hash_table_insert (g_dataset_location_ht,
-               (gpointer) dataset->location,
-               dataset);
+         (gpointer) dataset->location,
+         dataset);
     }
 
   g_data_set_internal (&dataset->datalist, key_id, data, destroy_func, dataset);
@@ -658,9 +658,9 @@ g_dataset_id_set_data_full (gconstpointer  dataset_location,
  **/
 void
 g_datalist_id_set_data_full (GData    **datalist,
-                             GQuark         key_id,
-                             gpointer       data,
-                             GDestroyNotify destroy_func)
+           GQuark         key_id,
+           gpointer       data,
+           GDestroyNotify destroy_func)
 {
   g_return_if_fail (datalist != NULL);
   if (!data)
@@ -668,9 +668,9 @@ g_datalist_id_set_data_full (GData    **datalist,
   if (!key_id)
     {
       if (data)
-    g_return_if_fail (key_id > 0);
+  g_return_if_fail (key_id > 0);
       else
-    return;
+  return;
     }
 
   g_data_set_internal (datalist, key_id, data, destroy_func, NULL);
@@ -696,7 +696,7 @@ g_datalist_id_set_data_full (GData    **datalist,
  **/
 gpointer
 g_dataset_id_remove_no_notify (gconstpointer  dataset_location,
-                   GQuark         key_id)
+             GQuark         key_id)
 {
   gpointer ret_data = NULL;
 
@@ -709,7 +709,7 @@ g_dataset_id_remove_no_notify (gconstpointer  dataset_location,
 
       dataset = g_dataset_lookup (dataset_location);
       if (dataset)
-    ret_data = g_data_set_internal (&dataset->datalist, key_id, NULL, (GDestroyNotify) 42, dataset);
+  ret_data = g_data_set_internal (&dataset->datalist, key_id, NULL, (GDestroyNotify) 42, dataset);
     }
   G_UNLOCK (g_dataset_global);
 
@@ -735,8 +735,8 @@ g_dataset_id_remove_no_notify (gconstpointer  dataset_location,
  * Removes an element, without calling its destroy notifier.
  **/
 gpointer
-g_datalist_id_remove_no_notify (GData   **datalist,
-                                GQuark    key_id)
+g_datalist_id_remove_no_notify (GData **datalist,
+        GQuark    key_id)
 {
   gpointer ret_data = NULL;
 
@@ -770,7 +770,7 @@ g_datalist_id_remove_no_notify (GData   **datalist,
  **/
 gpointer
 g_dataset_id_get_data (gconstpointer  dataset_location,
-                       GQuark         key_id)
+           GQuark         key_id)
 {
   gpointer retval = NULL;
 
@@ -783,7 +783,7 @@ g_dataset_id_get_data (gconstpointer  dataset_location,
 
       dataset = g_dataset_lookup (dataset_location);
       if (dataset)
-    retval = g_datalist_id_get_data (&dataset->datalist, key_id);
+  retval = g_datalist_id_get_data (&dataset->datalist, key_id);
     }
   G_UNLOCK (g_dataset_global);
 
@@ -802,7 +802,7 @@ g_dataset_id_get_data (gconstpointer  dataset_location,
  */
 gpointer
 g_datalist_id_get_data (GData  **datalist,
-                        GQuark   key_id)
+      GQuark   key_id)
 {
   return g_datalist_id_dup_data (datalist, key_id, NULL, NULL);
 }
@@ -984,7 +984,7 @@ g_datalist_id_replace_data (GData          **datalist,
       /* insert newval */
       old_d = d;
       if (d == NULL)
-    {
+  {
           d = g_malloc (sizeof (GData));
           d->len = 0;
           d->alloc = 1;
@@ -1021,7 +1021,7 @@ g_datalist_id_replace_data (GData          **datalist,
  **/
 gpointer
 g_datalist_get_data (GData   **datalist,
-                     const gchar *key)
+         const gchar *key)
 {
   gpointer res = NULL;
   GData *d;
@@ -1037,14 +1037,14 @@ g_datalist_get_data (GData   **datalist,
       data = d->data;
       data_end = data + d->len;
       while (data < data_end)
-    {
-      if (g_strcmp0 (g_quark_to_string (data->key), key) == 0)
-        {
-          res = data->data;
-          break;
-        }
-      data++;
-    }
+  {
+    if (g_strcmp0 (g_quark_to_string (data->key), key) == 0)
+      {
+        res = data->data;
+        break;
+      }
+    data++;
+  }
     }
 
   g_datalist_unlock (datalist);
@@ -1080,8 +1080,8 @@ g_datalist_get_data (GData   **datalist,
  **/
 void
 g_dataset_foreach (gconstpointer    dataset_location,
-           GDataForeachFunc func,
-           gpointer         user_data)
+       GDataForeachFunc func,
+       gpointer         user_data)
 {
   GDataset *dataset;
 
@@ -1094,7 +1094,7 @@ g_dataset_foreach (gconstpointer    dataset_location,
       dataset = g_dataset_lookup (dataset_location);
       G_UNLOCK (g_dataset_global);
       if (dataset)
-    g_datalist_foreach (&dataset->datalist, func, user_data);
+  g_datalist_foreach (&dataset->datalist, func, user_data);
     }
   else
     {
@@ -1120,12 +1120,12 @@ g_dataset_foreach (gconstpointer    dataset_location,
  * than skipping over elements that are removed.
  **/
 void
-g_datalist_foreach (GData      **datalist,
-                    GDataForeachFunc func,
-                    gpointer         user_data)
+g_datalist_foreach (GData    **datalist,
+        GDataForeachFunc func,
+        gpointer         user_data)
 {
   GData *d;
-  int i, j, len;
+  guint i, j, len;
   GQuark *keys;
 
   g_return_if_fail (datalist != NULL);
@@ -1145,18 +1145,18 @@ g_datalist_foreach (GData      **datalist,
   for (i = 0; i < len; i++)
     {
       /* A previous callback might have removed a later item, so always check that
-     it still exists before calling */
+   it still exists before calling */
       d = G_DATALIST_GET_POINTER (datalist);
 
       if (d == NULL)
-    break;
+  break;
       for (j = 0; j < d->len; j++)
-    {
-      if (d->data[j].key == keys[i]) {
-        func (d->data[i].key, d->data[i].data, user_data);
-        break;
-      }
+  {
+    if (d->data[j].key == keys[i]) {
+      func (d->data[i].key, d->data[i].data, user_data);
+      break;
     }
+  }
     }
   g_free (keys);
 }
@@ -1196,7 +1196,7 @@ g_datalist_init (GData **datalist)
  **/
 void
 g_datalist_set_flags (GData **datalist,
-                      guint   flags)
+          guint   flags)
 {
   g_return_if_fail (datalist != NULL);
   g_return_if_fail ((flags & ~G_DATALIST_FLAGS_MASK) == 0);
@@ -1219,7 +1219,7 @@ g_datalist_set_flags (GData **datalist,
  **/
 void
 g_datalist_unset_flags (GData **datalist,
-                        guint   flags)
+      guint   flags)
 {
   g_return_if_fail (datalist != NULL);
   g_return_if_fail ((flags & ~G_DATALIST_FLAGS_MASK) == 0);
