@@ -39,7 +39,6 @@
 #include "gstrfuncs.h"
 #include "gtestutils.h"
 #include "glibintl.h"
-#include "gunicodeprivate.h"
 
 
 /**
@@ -153,25 +152,25 @@
 #define G_IO_NICE_BUF_SIZE  1024
 
 /* This needs to be as wide as the largest character in any possible encoding */
-#define MAX_CHAR_SIZE       10
+#define MAX_CHAR_SIZE   10
 
 /* Some simplifying macros, which reduce the need to worry whether the
  * buffers have been allocated. These also make USE_BUF () an lvalue,
  * which is used in g_io_channel_read_to_end ().
  */
-#define USE_BUF(channel)    ((channel)->encoding ? (channel)->encoded_read_buf \
-                 : (channel)->read_buf)
-#define BUF_LEN(string)     ((string) ? (string)->len : 0)
+#define USE_BUF(channel)  ((channel)->encoding ? (channel)->encoded_read_buf \
+         : (channel)->read_buf)
+#define BUF_LEN(string)   ((string) ? (string)->len : 0)
 
-static GIOError     g_io_error_get_from_g_error (GIOStatus    status,
-                             GError      *err);
-static void     g_io_channel_purge      (GIOChannel  *channel);
-static GIOStatus    g_io_channel_fill_buffer    (GIOChannel  *channel,
-                             GError     **err);
-static GIOStatus    g_io_channel_read_line_backend  (GIOChannel  *channel,
-                             gsize       *length,
-                             gsize       *terminator_pos,
-                             GError     **error);
+static GIOError   g_io_error_get_from_g_error (GIOStatus    status,
+               GError      *err);
+static void   g_io_channel_purge    (GIOChannel  *channel);
+static GIOStatus  g_io_channel_fill_buffer  (GIOChannel  *channel,
+               GError     **err);
+static GIOStatus  g_io_channel_read_line_backend  (GIOChannel  *channel,
+               gsize       *length,
+               gsize       *terminator_pos,
+               GError     **error);
 
 /**
  * g_io_channel_init:
@@ -259,7 +258,7 @@ g_io_channel_unref (GIOChannel *channel)
 
 static GIOError
 g_io_error_get_from_g_error (GIOStatus  status,
-                 GError    *err)
+           GError    *err)
 {
   switch (status)
     {
@@ -269,7 +268,7 @@ g_io_error_get_from_g_error (GIOStatus  status,
       case G_IO_STATUS_AGAIN:
         return G_IO_ERROR_AGAIN;
       case G_IO_STATUS_ERROR:
-    g_return_val_if_fail (err != NULL, G_IO_ERROR_UNKNOWN);
+  g_return_val_if_fail (err != NULL, G_IO_ERROR_UNKNOWN);
 
         if (err->domain != G_IO_CHANNEL_ERROR)
           return G_IO_ERROR_UNKNOWN;
@@ -301,9 +300,9 @@ g_io_error_get_from_g_error (GIOStatus  status,
  **/
 GIOError
 g_io_channel_read (GIOChannel *channel,
-           gchar      *buf,
-           gsize       count,
-           gsize      *bytes_read)
+       gchar      *buf,
+       gsize       count,
+       gsize      *bytes_read)
 {
   GError *err = NULL;
   GIOError error;
@@ -346,9 +345,9 @@ g_io_channel_read (GIOChannel *channel,
  **/
 GIOError
 g_io_channel_write (GIOChannel  *channel,
-            const gchar *buf,
-            gsize        count,
-            gsize       *bytes_written)
+        const gchar *buf,
+        gsize        count,
+        gsize       *bytes_written)
 {
   GError *err = NULL;
   GIOError error;
@@ -385,8 +384,8 @@ g_io_channel_write (GIOChannel  *channel,
  **/
 GIOError
 g_io_channel_seek (GIOChannel *channel,
-           gint64      offset,
-           GSeekType   type)
+       gint64      offset,
+       GSeekType   type)
 {
   GError *err = NULL;
   GIOError error;
@@ -483,8 +482,8 @@ g_io_channel_close (GIOChannel *channel)
  **/
 GIOStatus
 g_io_channel_shutdown (GIOChannel  *channel,
-               gboolean     flush,
-               GError     **err)
+           gboolean     flush,
+           GError     **err)
 {
   GIOStatus status, result;
   GError *tmperr = NULL;
@@ -609,7 +608,7 @@ g_io_channel_purge (GIOChannel *channel)
  */
 GSource *
 g_io_create_watch (GIOChannel   *channel,
-           GIOCondition  condition)
+       GIOCondition  condition)
 {
   g_return_val_if_fail (channel != NULL, NULL);
 
@@ -636,11 +635,11 @@ g_io_create_watch (GIOChannel   *channel,
  */
 guint
 g_io_add_watch_full (GIOChannel    *channel,
-             gint           priority,
-             GIOCondition   condition,
-             GIOFunc        func,
-             gpointer       user_data,
-             GDestroyNotify notify)
+         gint           priority,
+         GIOCondition   condition,
+         GIOFunc        func,
+         gpointer       user_data,
+         GDestroyNotify notify)
 {
   GSource *source;
   guint id;
@@ -699,9 +698,9 @@ g_io_add_watch_full (GIOChannel    *channel,
  **/
 guint
 g_io_add_watch (GIOChannel   *channel,
-        GIOCondition  condition,
-        GIOFunc       func,
-        gpointer      user_data)
+    GIOCondition  condition,
+    GIOFunc       func,
+    gpointer      user_data)
 {
   return g_io_add_watch_full (channel, G_PRIORITY_DEFAULT, condition, func, user_data, NULL);
 }
@@ -882,7 +881,7 @@ g_io_channel_get_buffer_size (GIOChannel *channel)
 void
 g_io_channel_set_line_term (GIOChannel  *channel,
                             const gchar *line_term,
-                gint         length)
+          gint         length)
 {
   g_return_if_fail (channel != NULL);
   g_return_if_fail (line_term == NULL || length != 0); /* Disallow "" */
@@ -911,7 +910,7 @@ g_io_channel_set_line_term (GIOChannel  *channel,
  **/
 const gchar *
 g_io_channel_get_line_term (GIOChannel *channel,
-                gint       *length)
+          gint       *length)
 {
   g_return_val_if_fail (channel != NULL, NULL);
 
@@ -965,11 +964,11 @@ g_io_channel_set_flags (GIOChannel  *channel,
 {
   g_return_val_if_fail (channel != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail ((error == NULL) || (*error == NULL),
-            G_IO_STATUS_ERROR);
+      G_IO_STATUS_ERROR);
 
   return (*channel->funcs->io_set_flags) (channel,
-                      flags & G_IO_FLAG_SET_MASK,
-                      error);
+            flags & G_IO_FLAG_SET_MASK,
+            error);
 }
 
 /**
@@ -1024,7 +1023,7 @@ g_io_channel_get_flags (GIOChannel *channel)
  **/
 void
 g_io_channel_set_close_on_unref (GIOChannel *channel,
-                                 gboolean    do_close)
+         gboolean    do_close)
 {
   g_return_if_fail (channel != NULL);
 
@@ -1087,7 +1086,7 @@ g_io_channel_seek_position (GIOChannel  *channel,
 
   g_return_val_if_fail (channel != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail ((error == NULL) || (*error == NULL),
-            G_IO_STATUS_ERROR);
+      G_IO_STATUS_ERROR);
   g_return_val_if_fail (channel->is_seekable, G_IO_STATUS_ERROR);
 
   switch (type)
@@ -1174,7 +1173,7 @@ g_io_channel_seek_position (GIOChannel  *channel,
  **/
 GIOStatus
 g_io_channel_flush (GIOChannel  *channel,
-                    GError     **error)
+        GError     **error)
 {
   GIOStatus status;
   gsize this_time = 1, bytes_written = 0;
@@ -1190,9 +1189,9 @@ g_io_channel_flush (GIOChannel  *channel,
       g_assert (this_time > 0);
 
       status = channel->funcs->io_write (channel,
-                     channel->write_buf->str + bytes_written,
-                     channel->write_buf->len - bytes_written,
-                     &this_time, error);
+           channel->write_buf->str + bytes_written,
+           channel->write_buf->len - bytes_written,
+           &this_time, error);
       bytes_written += this_time;
     }
   while ((bytes_written < channel->write_buf->len)
@@ -1307,12 +1306,14 @@ g_io_channel_get_buffered (GIOChannel *channel)
  * Return Value: %G_IO_STATUS_NORMAL if the encoding was successfully set
  */
 GIOStatus
-g_io_channel_set_encoding (GIOChannel   *channel,
+g_io_channel_set_encoding (GIOChannel *channel,
                            const gchar  *encoding,
-                           GError      **error)
+         GError      **error)
 {
   GIConv read_cd, write_cd;
+#ifndef G_DISABLE_ASSERT
   gboolean did_encode;
+#endif
 
   g_return_val_if_fail (channel != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail ((error == NULL) || (*error == NULL), G_IO_STATUS_ERROR);
@@ -1320,7 +1321,7 @@ g_io_channel_set_encoding (GIOChannel   *channel,
   /* Make sure the encoded buffers are empty */
 
   g_return_val_if_fail (!channel->do_encode || !channel->encoded_read_buf ||
-            channel->encoded_read_buf->len == 0, G_IO_STATUS_ERROR);
+      channel->encoded_read_buf->len == 0, G_IO_STATUS_ERROR);
 
   if (!channel->use_buffer)
     {
@@ -1336,7 +1337,9 @@ g_io_channel_set_encoding (GIOChannel   *channel,
       channel->partial_write_buf[0] = '\0';
     }
 
+#ifndef G_DISABLE_ASSERT
   did_encode = channel->do_encode;
+#endif
 
   if (!encoding || strcmp (encoding, "UTF8") == 0 || strcmp (encoding, "UTF-8") == 0)
     {
@@ -1520,7 +1523,7 @@ reencode:
                - outbytes_left;
 
       errnum = g_iconv (channel->read_cd, &inbuf, &inbytes_left,
-            &outbuf, &outbytes_left);
+      &outbuf, &outbytes_left);
       errval = errno;
 
       g_assert (inbuf + inbytes_left == channel->read_buf->str
@@ -1529,9 +1532,9 @@ reencode:
                 + channel->encoded_read_buf->len);
 
       g_string_erase (channel->read_buf, 0,
-              channel->read_buf->len - inbytes_left);
+          channel->read_buf->len - inbytes_left);
       g_string_truncate (channel->encoded_read_buf,
-             channel->encoded_read_buf->len - outbytes_left);
+       channel->encoded_read_buf->len - outbytes_left);
 
       if (errnum == (gsize) -1)
         {
@@ -1644,8 +1647,8 @@ GIOStatus
 g_io_channel_read_line (GIOChannel  *channel,
                         gchar      **str_return,
                         gsize       *length,
-            gsize       *terminator_pos,
-                GError     **error)
+      gsize       *terminator_pos,
+            GError     **error)
 {
   GIOStatus status;
   gsize got_length;
@@ -1653,7 +1656,7 @@ g_io_channel_read_line (GIOChannel  *channel,
   g_return_val_if_fail (channel != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail (str_return != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail ((error == NULL) || (*error == NULL),
-            G_IO_STATUS_ERROR);
+      G_IO_STATUS_ERROR);
   g_return_val_if_fail (channel->is_readable, G_IO_STATUS_ERROR);
 
   status = g_io_channel_read_line_backend (channel, &got_length, terminator_pos, error);
@@ -1690,8 +1693,8 @@ g_io_channel_read_line (GIOChannel  *channel,
 GIOStatus
 g_io_channel_read_line_string (GIOChannel  *channel,
                                GString     *buffer,
-                               gsize       *terminator_pos,
-                               GError     **error)
+             gsize       *terminator_pos,
+                               GError   **error)
 {
   gsize length;
   GIOStatus status;
@@ -1699,7 +1702,7 @@ g_io_channel_read_line_string (GIOChannel  *channel,
   g_return_val_if_fail (channel != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail (buffer != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail ((error == NULL) || (*error == NULL),
-            G_IO_STATUS_ERROR);
+      G_IO_STATUS_ERROR);
   g_return_val_if_fail (channel->is_readable, G_IO_STATUS_ERROR);
 
   if (buffer->len > 0)
@@ -1869,9 +1872,9 @@ read_again:
         }
 
       if (use_buf->len > line_term_len - 1)
-    checked_to = use_buf->len - (line_term_len - 1);
+  checked_to = use_buf->len - (line_term_len - 1);
       else
-    checked_to = 0;
+  checked_to = 0;
     }
 
 done:
@@ -1958,9 +1961,9 @@ g_io_channel_read_to_end (GIOChannel  *channel,
         g_string_free (USE_BUF (channel), TRUE);
 
       if (channel->encoding)
-    channel->encoded_read_buf = NULL;
+  channel->encoded_read_buf = NULL;
       else
-    channel->read_buf = NULL;
+  channel->read_buf = NULL;
     }
 
   return G_IO_STATUS_NORMAL;
@@ -2100,15 +2103,15 @@ g_io_channel_read_chars (GIOChannel  *channel,
  **/
 GIOStatus
 g_io_channel_read_unichar (GIOChannel  *channel,
-               gunichar    *thechar,
-               GError     **error)
+         gunichar    *thechar,
+         GError     **error)
 {
   GIOStatus status = G_IO_STATUS_NORMAL;
 
   g_return_val_if_fail (channel != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail (channel->encoding != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail ((error == NULL) || (*error == NULL),
-            G_IO_STATUS_ERROR);
+      G_IO_STATUS_ERROR);
   g_return_val_if_fail (channel->is_readable, G_IO_STATUS_ERROR);
 
   while (BUF_LEN (channel->encoded_read_buf) == 0 && status == G_IO_STATUS_NORMAL)
@@ -2174,21 +2177,23 @@ GIOStatus
 g_io_channel_write_chars (GIOChannel   *channel,
                           const gchar  *buf,
                           gssize        count,
-              gsize        *bytes_written,
+        gsize        *bytes_written,
                           GError      **error)
 {
+  gsize count_unsigned;
   GIOStatus status;
   gssize wrote_bytes = 0;
 
   g_return_val_if_fail (channel != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail ((error == NULL) || (*error == NULL),
-            G_IO_STATUS_ERROR);
+      G_IO_STATUS_ERROR);
   g_return_val_if_fail (channel->is_writeable, G_IO_STATUS_ERROR);
 
   if ((count < 0) && buf)
     count = strlen (buf);
+  count_unsigned = count;
 
-  if (count == 0)
+  if (count_unsigned == 0)
     {
       if (bytes_written)
         *bytes_written = 0;
@@ -2196,7 +2201,7 @@ g_io_channel_write_chars (GIOChannel   *channel,
     }
 
   g_return_val_if_fail (buf != NULL, G_IO_STATUS_ERROR);
-  g_return_val_if_fail (count > 0, G_IO_STATUS_ERROR);
+  g_return_val_if_fail (count_unsigned > 0, G_IO_STATUS_ERROR);
 
   /* Raw write case */
 
@@ -2207,10 +2212,11 @@ g_io_channel_write_chars (GIOChannel   *channel,
       g_assert (!channel->write_buf || channel->write_buf->len == 0);
       g_assert (channel->partial_write_buf[0] == '\0');
 
-      status = channel->funcs->io_write (channel, buf, count, &tmp_bytes, error);
+      status = channel->funcs->io_write (channel, buf, count_unsigned,
+                                         &tmp_bytes, error);
 
       if (bytes_written)
-    *bytes_written = tmp_bytes;
+  *bytes_written = tmp_bytes;
 
       return status;
     }
@@ -2283,7 +2289,7 @@ g_io_channel_write_chars (GIOChannel   *channel,
 
       if (!channel->encoding)
         {
-          gssize write_this = MIN (space_in_buf, count - wrote_bytes);
+          gssize write_this = MIN (space_in_buf, count_unsigned - wrote_bytes);
 
           g_string_append_len (channel->write_buf, buf, write_this);
           buf += write_this;
@@ -2303,7 +2309,7 @@ g_io_channel_write_chars (GIOChannel   *channel,
               from_buf = channel->partial_write_buf;
               from_buf_old_len = strlen (channel->partial_write_buf);
               g_assert (from_buf_old_len > 0);
-              from_buf_len = MIN (6, from_buf_old_len + count);
+              from_buf_len = MIN (6, from_buf_old_len + count_unsigned);
 
               memcpy (channel->partial_write_buf + from_buf_old_len, buf,
                       from_buf_len - from_buf_old_len);
@@ -2311,7 +2317,7 @@ g_io_channel_write_chars (GIOChannel   *channel,
           else
             {
               from_buf = buf;
-              from_buf_len = count - wrote_bytes;
+              from_buf_len = count_unsigned - wrote_bytes;
               from_buf_old_len = 0;
             }
 
@@ -2324,7 +2330,7 @@ reconvert:
 
               /* UTF-8, just validate, emulate g_iconv */
 
-              if (!_g_utf8_validate_len (from_buf, try_len, &badchar))
+              if (!g_utf8_validate_len (from_buf, try_len, &badchar))
                 {
                   gunichar try_char;
                   gsize incomplete_len = from_buf + try_len - badchar;
@@ -2390,7 +2396,7 @@ reconvert:
           if (err == (gsize) -1)
             {
               switch (errnum)
-            {
+          {
                   case EINVAL:
                     g_assert (left_len < 6);
 
@@ -2401,7 +2407,7 @@ reconvert:
                         memcpy (channel->partial_write_buf, from_buf, left_len);
                         channel->partial_write_buf[left_len] = '\0';
                         if (bytes_written)
-                          *bytes_written = count;
+                          *bytes_written = count_unsigned;
                         return G_IO_STATUS_NORMAL;
                       }
 
@@ -2413,12 +2419,12 @@ reconvert:
                          * less than a full character
                          */
 
-                        g_assert (count == from_buf_len - from_buf_old_len);
+                        g_assert (count_unsigned == from_buf_len - from_buf_old_len);
 
                         channel->partial_write_buf[from_buf_len] = '\0';
 
                         if (bytes_written)
-                          *bytes_written = count;
+                          *bytes_written = count_unsigned;
 
                         return G_IO_STATUS_NORMAL;
                       }
@@ -2480,7 +2486,7 @@ reconvert:
     }
 
   if (bytes_written)
-    *bytes_written = count;
+    *bytes_written = count_unsigned;
 
   return G_IO_STATUS_NORMAL;
 }
@@ -2499,8 +2505,8 @@ reconvert:
  **/
 GIOStatus
 g_io_channel_write_unichar (GIOChannel  *channel,
-                gunichar     thechar,
-                GError     **error)
+          gunichar     thechar,
+          GError     **error)
 {
   GIOStatus status;
   gchar static_buf[6];
@@ -2509,7 +2515,7 @@ g_io_channel_write_unichar (GIOChannel  *channel,
   g_return_val_if_fail (channel != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail (channel->encoding != NULL, G_IO_STATUS_ERROR);
   g_return_val_if_fail ((error == NULL) || (*error == NULL),
-            G_IO_STATUS_ERROR);
+      G_IO_STATUS_ERROR);
   g_return_val_if_fail (channel->is_writeable, G_IO_STATUS_ERROR);
 
   char_len = g_unichar_to_utf8 (thechar, static_buf);
