@@ -31,7 +31,7 @@
 
 #include "config.h"
 
-#define _POSIX_SOURCE       /* for SSIZE_MAX */
+#define _POSIX_SOURCE   /* for SSIZE_MAX */
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -71,43 +71,44 @@ struct _GIOUnixWatch
 };
 
 
-static GIOStatus    g_io_unix_read      (GIOChannel   *channel,
-                         gchar        *buf,
-                         gsize         count,
-                         gsize        *bytes_read,
-                         GError      **err);
-static GIOStatus    g_io_unix_write     (GIOChannel   *channel,
-                         const gchar  *buf,
-                         gsize         count,
-                         gsize        *bytes_written,
-                         GError      **err);
-static GIOStatus    g_io_unix_seek      (GIOChannel   *channel,
-                         gint64        offset,
-                         GSeekType     type,
-                         GError      **err);
-static GIOStatus    g_io_unix_close     (GIOChannel   *channel,
-                         GError      **err);
-static void     g_io_unix_free      (GIOChannel   *channel);
-static GSource*     g_io_unix_create_watch  (GIOChannel   *channel,
-                         GIOCondition  condition);
-static GIOStatus    g_io_unix_set_flags (GIOChannel   *channel,
-                                     GIOFlags      flags,
-                         GError      **err);
-static GIOFlags     g_io_unix_get_flags (GIOChannel   *channel);
+static GIOStatus  g_io_unix_read    (GIOChannel   *channel,
+             gchar        *buf,
+             gsize         count,
+             gsize        *bytes_read,
+             GError      **err);
+static GIOStatus  g_io_unix_write   (GIOChannel   *channel,
+             const gchar  *buf,
+             gsize         count,
+             gsize        *bytes_written,
+             GError      **err);
+static GIOStatus  g_io_unix_seek    (GIOChannel   *channel,
+             gint64        offset,
+             GSeekType     type,
+             GError      **err);
+static GIOStatus  g_io_unix_close   (GIOChannel   *channel,
+             GError      **err);
+static void   g_io_unix_free    (GIOChannel   *channel);
+static GSource*   g_io_unix_create_watch  (GIOChannel   *channel,
+             GIOCondition  condition);
+static GIOStatus  g_io_unix_set_flags (GIOChannel   *channel,
+                               GIOFlags      flags,
+             GError      **err);
+static GIOFlags   g_io_unix_get_flags (GIOChannel   *channel);
 
 static gboolean g_io_unix_prepare  (GSource     *source,
-                    gint        *timeout);
+            gint        *timeout);
 static gboolean g_io_unix_check    (GSource     *source);
 static gboolean g_io_unix_dispatch (GSource     *source,
-                    GSourceFunc  callback,
-                    gpointer     user_data);
+            GSourceFunc  callback,
+            gpointer     user_data);
 static void     g_io_unix_finalize (GSource     *source);
 
 GSourceFuncs g_io_watch_funcs = {
   g_io_unix_prepare,
   g_io_unix_check,
   g_io_unix_dispatch,
-  g_io_unix_finalize
+  g_io_unix_finalize,
+  NULL, NULL
 };
 
 static GIOFuncs unix_channel_funcs = {
@@ -123,7 +124,7 @@ static GIOFuncs unix_channel_funcs = {
 
 static gboolean
 g_io_unix_prepare (GSource  *source,
-           gint     *timeout)
+       gint     *timeout)
 {
   GIOUnixWatch *watch = (GIOUnixWatch *)source;
   GIOCondition buffer_condition = g_io_channel_get_buffer_condition (watch->channel);
@@ -147,8 +148,8 @@ g_io_unix_check (GSource  *source)
 
 static gboolean
 g_io_unix_dispatch (GSource     *source,
-            GSourceFunc  callback,
-            gpointer     user_data)
+        GSourceFunc  callback,
+        gpointer     user_data)
 
 {
   GIOFunc func = (GIOFunc)callback;
@@ -158,13 +159,13 @@ g_io_unix_dispatch (GSource     *source,
   if (!func)
     {
       g_warning ("IO watch dispatched without callback. "
-         "You must call g_source_connect().");
+     "You must call g_source_connect().");
       return FALSE;
     }
 
   return (*func) (watch->channel,
-          (watch->pollfd.revents | buffer_condition) & watch->condition,
-          user_data);
+      (watch->pollfd.revents | buffer_condition) & watch->condition,
+      user_data);
 }
 
 static void
@@ -177,10 +178,10 @@ g_io_unix_finalize (GSource *source)
 
 static GIOStatus
 g_io_unix_read (GIOChannel *channel,
-        gchar      *buf,
-        gsize       count,
-        gsize      *bytes_read,
-        GError    **err)
+    gchar      *buf,
+    gsize       count,
+    gsize      *bytes_read,
+    GError    **err)
 {
   GIOUnixChannel *unix_channel = (GIOUnixChannel *)channel;
   gssize result;
@@ -221,10 +222,10 @@ g_io_unix_read (GIOChannel *channel,
 
 static GIOStatus
 g_io_unix_write (GIOChannel  *channel,
-         const gchar *buf,
-         gsize       count,
-         gsize      *bytes_written,
-         GError    **err)
+     const gchar *buf,
+     gsize       count,
+     gsize      *bytes_written,
+     GError    **err)
 {
   GIOUnixChannel *unix_channel = (GIOUnixChannel *)channel;
   gssize result;
@@ -262,8 +263,8 @@ g_io_unix_write (GIOChannel  *channel,
 
 static GIOStatus
 g_io_unix_seek (GIOChannel *channel,
-        gint64      offset,
-        GSeekType   type,
+    gint64      offset,
+    GSeekType   type,
                 GError    **err)
 {
   GIOUnixChannel *unix_channel = (GIOUnixChannel *)channel;
@@ -313,7 +314,7 @@ g_io_unix_seek (GIOChannel *channel,
 
 static GIOStatus
 g_io_unix_close (GIOChannel *channel,
-         GError    **err)
+     GError    **err)
 {
   GIOUnixChannel *unix_channel = (GIOUnixChannel *)channel;
 
@@ -339,7 +340,7 @@ g_io_unix_free (GIOChannel *channel)
 
 static GSource *
 g_io_unix_create_watch (GIOChannel   *channel,
-            GIOCondition  condition)
+      GIOCondition  condition)
 {
   GIOUnixChannel *unix_channel = (GIOUnixChannel *)channel;
   GSource *source;
@@ -407,7 +408,7 @@ g_io_unix_get_flags (GIOChannel *channel)
     {
       int err = errno;
       g_warning (G_STRLOC "Error while getting flags for FD: %s (%d)",
-         g_strerror (err), err);
+     g_strerror (err), err);
       return 0;
     }
 
