@@ -67,21 +67,21 @@
 
 
 /* --- prototypes --- */
-static void g_enum_class_init       (GEnumClass *class,
-                         gpointer    class_data);
-static void g_flags_class_init      (GFlagsClass    *class,
-                         gpointer    class_data);
-static void value_flags_enum_init       (GValue     *value);
-static void value_flags_enum_copy_value (const GValue   *src_value,
-                         GValue     *dest_value);
-static gchar*   value_flags_enum_collect_value  (GValue     *value,
-                         guint           n_collect_values,
-                         GTypeCValue    *collect_values,
-                         guint           collect_flags);
-static gchar*   value_flags_enum_lcopy_value    (const GValue   *value,
-                         guint           n_collect_values,
-                         GTypeCValue    *collect_values,
-                         guint           collect_flags);
+static void g_enum_class_init   (GEnumClass *class,
+             gpointer  class_data);
+static void g_flags_class_init    (GFlagsClass  *class,
+             gpointer  class_data);
+static void value_flags_enum_init   (GValue   *value);
+static void value_flags_enum_copy_value (const GValue *src_value,
+             GValue   *dest_value);
+static gchar* value_flags_enum_collect_value  (GValue   *value,
+             guint           n_collect_values,
+             GTypeCValue    *collect_values,
+             guint           collect_flags);
+static gchar* value_flags_enum_lcopy_value  (const GValue *value,
+             guint           n_collect_values,
+             GTypeCValue    *collect_values,
+             guint           collect_flags);
 
 /* --- functions --- */
 void
@@ -90,12 +90,12 @@ _g_enum_types_init (void)
   static gboolean initialized = FALSE;
   static const GTypeValueTable flags_enum_value_table = {
     value_flags_enum_init,      /* value_init */
-    NULL,               /* value_free */
+    NULL,         /* value_free */
     value_flags_enum_copy_value,    /* value_copy */
-    NULL,               /* value_peek_pointer */
-    "i",                /* collect_format */
+    NULL,         /* value_peek_pointer */
+    "i",          /* collect_format */
     value_flags_enum_collect_value, /* collect_value */
-    "p",                /* lcopy_format */
+    "p",          /* lcopy_format */
     value_flags_enum_lcopy_value,   /* lcopy_value */
   };
   GTypeInfo info = {
@@ -113,7 +113,7 @@ _g_enum_types_init (void)
   static const GTypeFundamentalInfo finfo = {
     G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_DERIVABLE,
   };
-  GType type;
+  GType type G_GNUC_UNUSED  /* when compiling with G_DISABLE_ASSERT */;
 
   g_return_if_fail (initialized == FALSE);
   initialized = TRUE;
@@ -122,14 +122,14 @@ _g_enum_types_init (void)
    */
   info.class_size = sizeof (GEnumClass);
   type = g_type_register_fundamental (G_TYPE_ENUM, g_intern_static_string ("GEnum"), &info, &finfo,
-                      G_TYPE_FLAG_ABSTRACT | G_TYPE_FLAG_VALUE_ABSTRACT);
+              G_TYPE_FLAG_ABSTRACT | G_TYPE_FLAG_VALUE_ABSTRACT);
   g_assert (type == G_TYPE_ENUM);
 
   /* G_TYPE_FLAGS
    */
   info.class_size = sizeof (GFlagsClass);
   type = g_type_register_fundamental (G_TYPE_FLAGS, g_intern_static_string ("GFlags"), &info, &finfo,
-                      G_TYPE_FLAG_ABSTRACT | G_TYPE_FLAG_VALUE_ABSTRACT);
+              G_TYPE_FLAG_ABSTRACT | G_TYPE_FLAG_VALUE_ABSTRACT);
   g_assert (type == G_TYPE_FLAGS);
 }
 
@@ -141,16 +141,16 @@ value_flags_enum_init (GValue *value)
 
 static void
 value_flags_enum_copy_value (const GValue *src_value,
-                 GValue   *dest_value)
+           GValue   *dest_value)
 {
   dest_value->data[0].v_long = src_value->data[0].v_long;
 }
 
 static gchar*
 value_flags_enum_collect_value (GValue      *value,
-                guint        n_collect_values,
-                GTypeCValue *collect_values,
-                guint        collect_flags)
+        guint        n_collect_values,
+        GTypeCValue *collect_values,
+        guint        collect_flags)
 {
   if (G_VALUE_HOLDS_ENUM (value))
     value->data[0].v_long = collect_values[0].v_int;
@@ -162,9 +162,9 @@ value_flags_enum_collect_value (GValue      *value,
 
 static gchar*
 value_flags_enum_lcopy_value (const GValue *value,
-                  guint         n_collect_values,
-                  GTypeCValue  *collect_values,
-                  guint         collect_flags)
+            guint         n_collect_values,
+            GTypeCValue  *collect_values,
+            guint         collect_flags)
 {
   gint *int_p = collect_values[0].v_pointer;
 
@@ -194,7 +194,7 @@ value_flags_enum_lcopy_value (const GValue *value,
  */
 GType
 g_enum_register_static (const gchar  *name,
-            const GEnumValue *const_static_values)
+      const GEnumValue *const_static_values)
 {
   GTypeInfo enum_type_info = {
     sizeof (GEnumClass), /* class_size */
@@ -206,7 +206,7 @@ g_enum_register_static (const gchar  *name,
     0,                   /* instance_size */
     0,                   /* n_preallocs */
     NULL,                /* instance_init */
-    NULL,        /* value_table */
+    NULL,    /* value_table */
   };
   GType type;
 
@@ -236,8 +236,8 @@ g_enum_register_static (const gchar  *name,
  * Returns: The new type identifier.
  */
 GType
-g_flags_register_static (const gchar       *name,
-             const GFlagsValue *const_static_values)
+g_flags_register_static (const gchar     *name,
+       const GFlagsValue *const_static_values)
 {
   GTypeInfo flags_type_info = {
     sizeof (GFlagsClass), /* class_size */
@@ -249,7 +249,7 @@ g_flags_register_static (const gchar       *name,
     0,                    /* instance_size */
     0,                    /* n_preallocs */
     NULL,                 /* instance_init */
-    NULL,         /* value_table */
+    NULL,     /* value_table */
   };
   GType type;
 
@@ -293,9 +293,9 @@ g_flags_register_static (const gchar       *name,
  * ]|
  */
 void
-g_enum_complete_type_info (GType         g_enum_type,
-               GTypeInfo        *info,
-               const GEnumValue *const_values)
+g_enum_complete_type_info (GType       g_enum_type,
+         GTypeInfo      *info,
+         const GEnumValue *const_values)
 {
   g_return_if_fail (G_TYPE_IS_ENUM (g_enum_type));
   g_return_if_fail (info != NULL);
@@ -322,9 +322,9 @@ g_enum_complete_type_info (GType         g_enum_type,
  * g_enum_complete_type_info() above.
  */
 void
-g_flags_complete_type_info (GType          g_flags_type,
-                GTypeInfo         *info,
-                const GFlagsValue *const_values)
+g_flags_complete_type_info (GType        g_flags_type,
+          GTypeInfo       *info,
+          const GFlagsValue *const_values)
 {
   g_return_if_fail (G_TYPE_IS_FLAGS (g_flags_type));
   g_return_if_fail (info != NULL);
@@ -340,7 +340,7 @@ g_flags_complete_type_info (GType          g_flags_type,
 
 static void
 g_enum_class_init (GEnumClass *class,
-           gpointer    class_data)
+       gpointer    class_data)
 {
   g_return_if_fail (G_IS_ENUM_CLASS (class));
 
@@ -356,17 +356,17 @@ g_enum_class_init (GEnumClass *class,
       class->minimum = class->values->value;
       class->maximum = class->values->value;
       for (values = class->values; values->value_name; values++)
-    {
-      class->minimum = MIN (class->minimum, values->value);
-      class->maximum = MAX (class->maximum, values->value);
-      class->n_values++;
-    }
+  {
+    class->minimum = MIN (class->minimum, values->value);
+    class->maximum = MAX (class->maximum, values->value);
+    class->n_values++;
+  }
     }
 }
 
 static void
 g_flags_class_init (GFlagsClass *class,
-            gpointer     class_data)
+        gpointer   class_data)
 {
   g_return_if_fail (G_IS_FLAGS_CLASS (class));
 
@@ -379,10 +379,10 @@ g_flags_class_init (GFlagsClass *class,
       GFlagsValue *values;
 
       for (values = class->values; values->value_name; values++)
-    {
-      class->mask |= values->value;
-      class->n_values++;
-    }
+  {
+    class->mask |= values->value;
+    class->n_values++;
+  }
     }
 }
 
@@ -399,7 +399,7 @@ g_flags_class_init (GFlagsClass *class,
  */
 GEnumValue*
 g_enum_get_value_by_name (GEnumClass  *enum_class,
-              const gchar *name)
+        const gchar *name)
 {
   g_return_val_if_fail (G_IS_ENUM_CLASS (enum_class), NULL);
   g_return_val_if_fail (name != NULL, NULL);
@@ -409,8 +409,8 @@ g_enum_get_value_by_name (GEnumClass  *enum_class,
       GEnumValue *enum_value;
 
       for (enum_value = enum_class->values; enum_value->value_name; enum_value++)
-    if (strcmp (name, enum_value->value_name) == 0)
-      return enum_value;
+  if (strcmp (name, enum_value->value_name) == 0)
+    return enum_value;
     }
 
   return NULL;
@@ -428,7 +428,7 @@ g_enum_get_value_by_name (GEnumClass  *enum_class,
  */
 GFlagsValue*
 g_flags_get_value_by_name (GFlagsClass *flags_class,
-               const gchar *name)
+         const gchar *name)
 {
   g_return_val_if_fail (G_IS_FLAGS_CLASS (flags_class), NULL);
   g_return_val_if_fail (name != NULL, NULL);
@@ -438,8 +438,8 @@ g_flags_get_value_by_name (GFlagsClass *flags_class,
       GFlagsValue *flags_value;
 
       for (flags_value = flags_class->values; flags_value->value_name; flags_value++)
-    if (strcmp (name, flags_value->value_name) == 0)
-      return flags_value;
+  if (strcmp (name, flags_value->value_name) == 0)
+    return flags_value;
     }
 
   return NULL;
@@ -458,7 +458,7 @@ g_flags_get_value_by_name (GFlagsClass *flags_class,
  */
 GEnumValue*
 g_enum_get_value_by_nick (GEnumClass  *enum_class,
-              const gchar *nick)
+        const gchar *nick)
 {
   g_return_val_if_fail (G_IS_ENUM_CLASS (enum_class), NULL);
   g_return_val_if_fail (nick != NULL, NULL);
@@ -468,8 +468,8 @@ g_enum_get_value_by_nick (GEnumClass  *enum_class,
       GEnumValue *enum_value;
 
       for (enum_value = enum_class->values; enum_value->value_name; enum_value++)
-    if (enum_value->value_nick && strcmp (nick, enum_value->value_nick) == 0)
-      return enum_value;
+  if (enum_value->value_nick && strcmp (nick, enum_value->value_nick) == 0)
+    return enum_value;
     }
 
   return NULL;
@@ -487,7 +487,7 @@ g_enum_get_value_by_nick (GEnumClass  *enum_class,
  */
 GFlagsValue*
 g_flags_get_value_by_nick (GFlagsClass *flags_class,
-               const gchar *nick)
+         const gchar *nick)
 {
   g_return_val_if_fail (G_IS_FLAGS_CLASS (flags_class), NULL);
   g_return_val_if_fail (nick != NULL, NULL);
@@ -497,8 +497,8 @@ g_flags_get_value_by_nick (GFlagsClass *flags_class,
       GFlagsValue *flags_value;
 
       for (flags_value = flags_class->values; flags_value->value_nick; flags_value++)
-    if (flags_value->value_nick && strcmp (nick, flags_value->value_nick) == 0)
-      return flags_value;
+  if (flags_value->value_nick && strcmp (nick, flags_value->value_nick) == 0)
+    return flags_value;
     }
 
   return NULL;
@@ -516,7 +516,7 @@ g_flags_get_value_by_nick (GFlagsClass *flags_class,
  */
 GEnumValue*
 g_enum_get_value (GEnumClass *enum_class,
-          gint        value)
+      gint        value)
 {
   g_return_val_if_fail (G_IS_ENUM_CLASS (enum_class), NULL);
 
@@ -525,8 +525,8 @@ g_enum_get_value (GEnumClass *enum_class,
       GEnumValue *enum_value;
 
       for (enum_value = enum_class->values; enum_value->value_name; enum_value++)
-    if (enum_value->value == value)
-      return enum_value;
+  if (enum_value->value == value)
+    return enum_value;
     }
 
   return NULL;
@@ -544,7 +544,7 @@ g_enum_get_value (GEnumClass *enum_class,
  */
 GFlagsValue*
 g_flags_get_first_value (GFlagsClass *flags_class,
-             guint        value)
+       guint        value)
 {
   g_return_val_if_fail (G_IS_FLAGS_CLASS (flags_class), NULL);
 
@@ -705,7 +705,7 @@ g_flags_to_string (GType flags_type,
  */
 void
 g_value_set_enum (GValue *value,
-          gint    v_enum)
+      gint    v_enum)
 {
   g_return_if_fail (G_VALUE_HOLDS_ENUM (value));
 
@@ -737,7 +737,7 @@ g_value_get_enum (const GValue *value)
  */
 void
 g_value_set_flags (GValue *value,
-           guint   v_flags)
+       guint   v_flags)
 {
   g_return_if_fail (G_VALUE_HOLDS_FLAGS (value));
 
