@@ -1,6 +1,6 @@
 /* GObject - GLib Type, Object, Parameter and Signal Library
  * Copyright (C) 1997-1999, 2000-2001 Tim Janik and Red Hat, Inc.
- * Copyright  2010 Christian Persch
+ * Copyright (C) 2010 Christian Persch
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -43,16 +43,16 @@ value_init_long0 (GValue *value)
 
 static void
 value_copy_long0 (const GValue *src_value,
-          GValue       *dest_value)
+      GValue       *dest_value)
 {
   dest_value->data[0].v_long = src_value->data[0].v_long;
 }
 
 static gchar*
 value_lcopy_char (const GValue *value,
-          guint         n_collect_values,
-          GTypeCValue  *collect_values,
-          guint         collect_flags)
+      guint         n_collect_values,
+      GTypeCValue  *collect_values,
+      guint         collect_flags)
 {
   gint8 *int8_p = collect_values[0].v_pointer;
 
@@ -66,9 +66,9 @@ value_lcopy_char (const GValue *value,
 
 static gchar*
 value_lcopy_boolean (const GValue *value,
-             guint         n_collect_values,
-             GTypeCValue  *collect_values,
-             guint         collect_flags)
+         guint         n_collect_values,
+         GTypeCValue  *collect_values,
+         guint         collect_flags)
 {
   gboolean *bool_p = collect_values[0].v_pointer;
 
@@ -82,9 +82,9 @@ value_lcopy_boolean (const GValue *value,
 
 static gchar*
 value_collect_int (GValue      *value,
-           guint        n_collect_values,
-           GTypeCValue *collect_values,
-           guint        collect_flags)
+       guint        n_collect_values,
+       GTypeCValue *collect_values,
+       guint        collect_flags)
 {
   value->data[0].v_int = collect_values[0].v_int;
 
@@ -93,9 +93,9 @@ value_collect_int (GValue      *value,
 
 static gchar*
 value_lcopy_int (const GValue *value,
-         guint         n_collect_values,
-         GTypeCValue  *collect_values,
-         guint         collect_flags)
+     guint         n_collect_values,
+     GTypeCValue  *collect_values,
+     guint         collect_flags)
 {
   gint *int_p = collect_values[0].v_pointer;
 
@@ -109,9 +109,9 @@ value_lcopy_int (const GValue *value,
 
 static gchar*
 value_collect_long (GValue      *value,
-            guint        n_collect_values,
-            GTypeCValue *collect_values,
-            guint        collect_flags)
+        guint        n_collect_values,
+        GTypeCValue *collect_values,
+        guint        collect_flags)
 {
   value->data[0].v_long = collect_values[0].v_long;
 
@@ -120,9 +120,9 @@ value_collect_long (GValue      *value,
 
 static gchar*
 value_lcopy_long (const GValue *value,
-          guint         n_collect_values,
-          GTypeCValue  *collect_values,
-          guint         collect_flags)
+      guint         n_collect_values,
+      GTypeCValue  *collect_values,
+      guint         collect_flags)
 {
   glong *long_p = collect_values[0].v_pointer;
 
@@ -142,16 +142,16 @@ value_init_int64 (GValue *value)
 
 static void
 value_copy_int64 (const GValue *src_value,
-          GValue       *dest_value)
+      GValue       *dest_value)
 {
   dest_value->data[0].v_int64 = src_value->data[0].v_int64;
 }
 
 static gchar*
 value_collect_int64 (GValue      *value,
-             guint        n_collect_values,
-             GTypeCValue *collect_values,
-             guint        collect_flags)
+         guint        n_collect_values,
+         GTypeCValue *collect_values,
+         guint        collect_flags)
 {
   value->data[0].v_int64 = collect_values[0].v_int64;
 
@@ -160,9 +160,9 @@ value_collect_int64 (GValue      *value,
 
 static gchar*
 value_lcopy_int64 (const GValue *value,
-           guint         n_collect_values,
-           GTypeCValue  *collect_values,
-           guint         collect_flags)
+       guint         n_collect_values,
+       GTypeCValue  *collect_values,
+       guint         collect_flags)
 {
   gint64 *int64_p = collect_values[0].v_pointer;
 
@@ -182,16 +182,16 @@ value_init_float (GValue *value)
 
 static void
 value_copy_float (const GValue *src_value,
-          GValue       *dest_value)
+      GValue       *dest_value)
 {
   dest_value->data[0].v_float = src_value->data[0].v_float;
 }
 
 static gchar*
 value_collect_float (GValue      *value,
-             guint        n_collect_values,
-             GTypeCValue *collect_values,
-             guint        collect_flags)
+         guint        n_collect_values,
+         GTypeCValue *collect_values,
+         guint        collect_flags)
 {
   value->data[0].v_float = collect_values[0].v_double;
 
@@ -200,9 +200,9 @@ value_collect_float (GValue      *value,
 
 static gchar*
 value_lcopy_float (const GValue *value,
-           guint         n_collect_values,
-           GTypeCValue  *collect_values,
-           guint         collect_flags)
+       guint         n_collect_values,
+       GTypeCValue  *collect_values,
+       guint         collect_flags)
 {
   gfloat *float_p = collect_values[0].v_pointer;
 
@@ -222,16 +222,16 @@ value_init_double (GValue *value)
 
 static void
 value_copy_double (const GValue *src_value,
-           GValue   *dest_value)
+       GValue *dest_value)
 {
   dest_value->data[0].v_double = src_value->data[0].v_double;
 }
 
 static gchar*
-value_collect_double (GValue      *value,
-              guint        n_collect_values,
-              GTypeCValue *collect_values,
-              guint        collect_flags)
+value_collect_double (GValue    *value,
+          guint        n_collect_values,
+          GTypeCValue *collect_values,
+          guint        collect_flags)
 {
   value->data[0].v_double = collect_values[0].v_double;
 
@@ -240,9 +240,9 @@ value_collect_double (GValue      *value,
 
 static gchar*
 value_lcopy_double (const GValue *value,
-            guint         n_collect_values,
-            GTypeCValue  *collect_values,
-            guint         collect_flags)
+        guint         n_collect_values,
+        GTypeCValue  *collect_values,
+        guint         collect_flags)
 {
   gdouble *double_p = collect_values[0].v_pointer;
 
@@ -269,16 +269,16 @@ value_free_string (GValue *value)
 
 static void
 value_copy_string (const GValue *src_value,
-           GValue   *dest_value)
+       GValue *dest_value)
 {
   dest_value->data[0].v_pointer = g_strdup (src_value->data[0].v_pointer);
 }
 
 static gchar*
-value_collect_string (GValue      *value,
-              guint        n_collect_values,
-              GTypeCValue *collect_values,
-              guint        collect_flags)
+value_collect_string (GValue    *value,
+          guint        n_collect_values,
+          GTypeCValue *collect_values,
+          guint        collect_flags)
 {
   if (!collect_values[0].v_pointer)
     value->data[0].v_pointer = NULL;
@@ -295,9 +295,9 @@ value_collect_string (GValue      *value,
 
 static gchar*
 value_lcopy_string (const GValue *value,
-            guint         n_collect_values,
-            GTypeCValue  *collect_values,
-            guint         collect_flags)
+        guint         n_collect_values,
+        GTypeCValue  *collect_values,
+        guint         collect_flags)
 {
   gchar **string_p = collect_values[0].v_pointer;
 
@@ -322,7 +322,7 @@ value_init_pointer (GValue *value)
 
 static void
 value_copy_pointer (const GValue *src_value,
-            GValue       *dest_value)
+        GValue       *dest_value)
 {
   dest_value->data[0].v_pointer = src_value->data[0].v_pointer;
 }
@@ -335,9 +335,9 @@ value_peek_pointer0 (const GValue *value)
 
 static gchar*
 value_collect_pointer (GValue      *value,
-               guint        n_collect_values,
-               GTypeCValue *collect_values,
-               guint        collect_flags)
+           guint        n_collect_values,
+           GTypeCValue *collect_values,
+           guint        collect_flags)
 {
   value->data[0].v_pointer = collect_values[0].v_pointer;
 
@@ -346,9 +346,9 @@ value_collect_pointer (GValue      *value,
 
 static gchar*
 value_lcopy_pointer (const GValue *value,
-             guint         n_collect_values,
-             GTypeCValue  *collect_values,
-             guint         collect_flags)
+         guint         n_collect_values,
+         GTypeCValue  *collect_values,
+         guint         collect_flags)
 {
   gpointer *pointer_p = collect_values[0].v_pointer;
 
@@ -370,7 +370,7 @@ value_free_variant (GValue *value)
 
 static void
 value_copy_variant (const GValue *src_value,
-           GValue   *dest_value)
+       GValue *dest_value)
 {
   if (src_value->data[0].v_pointer)
     dest_value->data[0].v_pointer = g_variant_ref_sink (src_value->data[0].v_pointer);
@@ -379,10 +379,10 @@ value_copy_variant (const GValue *src_value,
 }
 
 static gchar*
-value_collect_variant (GValue     *value,
-              guint        n_collect_values,
-              GTypeCValue *collect_values,
-              guint        collect_flags)
+value_collect_variant (GValue   *value,
+          guint        n_collect_values,
+          GTypeCValue *collect_values,
+          guint        collect_flags)
 {
   if (!collect_values[0].v_pointer)
     value->data[0].v_pointer = NULL;
@@ -399,9 +399,9 @@ value_collect_variant (GValue     *value,
 
 static gchar*
 value_lcopy_variant (const GValue *value,
-            guint         n_collect_values,
-            GTypeCValue  *collect_values,
-            guint         collect_flags)
+        guint         n_collect_values,
+        GTypeCValue  *collect_values,
+        guint         collect_flags)
 {
   GVariant **variant_p = collect_values[0].v_pointer;
 
@@ -423,32 +423,32 @@ void
 _g_value_types_init (void)
 {
   GTypeInfo info = {
-    0,              /* class_size */
-    NULL,           /* base_init */
-    NULL,           /* base_destroy */
-    NULL,           /* class_init */
-    NULL,           /* class_destroy */
-    NULL,           /* class_data */
-    0,              /* instance_size */
-    0,              /* n_preallocs */
-    NULL,           /* instance_init */
-    NULL,           /* value_table */
+    0,        /* class_size */
+    NULL,     /* base_init */
+    NULL,     /* base_destroy */
+    NULL,     /* class_init */
+    NULL,     /* class_destroy */
+    NULL,     /* class_data */
+    0,        /* instance_size */
+    0,        /* n_preallocs */
+    NULL,     /* instance_init */
+    NULL,     /* value_table */
   };
   const GTypeFundamentalInfo finfo = { G_TYPE_FLAG_DERIVABLE, };
-  GType type;
+  GType type G_GNUC_UNUSED  /* when compiling with G_DISABLE_ASSERT */;
 
   /* G_TYPE_CHAR / G_TYPE_UCHAR
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_long0,     /* value_init */
-      NULL,         /* value_free */
-      value_copy_long0,     /* value_copy */
-      NULL,         /* value_peek_pointer */
-      "i",          /* collect_format */
-      value_collect_int,    /* collect_value */
-      "p",          /* lcopy_format */
-      value_lcopy_char,     /* lcopy_value */
+      value_init_long0,   /* value_init */
+      NULL,     /* value_free */
+      value_copy_long0,   /* value_copy */
+      NULL,     /* value_peek_pointer */
+      "i",      /* collect_format */
+      value_collect_int,  /* collect_value */
+      "p",      /* lcopy_format */
+      value_lcopy_char,   /* lcopy_value */
     };
     info.value_table = &value_table;
     type = g_type_register_fundamental (G_TYPE_CHAR, g_intern_static_string ("gchar"), &info, &finfo, 0);
@@ -461,13 +461,13 @@ _g_value_types_init (void)
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_long0,      /* value_init */
-      NULL,          /* value_free */
-      value_copy_long0,      /* value_copy */
+      value_init_long0,    /* value_init */
+      NULL,      /* value_free */
+      value_copy_long0,    /* value_copy */
       NULL,                      /* value_peek_pointer */
-      "i",           /* collect_format */
-      value_collect_int,     /* collect_value */
-      "p",           /* lcopy_format */
+      "i",       /* collect_format */
+      value_collect_int,   /* collect_value */
+      "p",       /* lcopy_format */
       value_lcopy_boolean,   /* lcopy_value */
     };
     info.value_table = &value_table;
@@ -479,14 +479,14 @@ _g_value_types_init (void)
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_long0,     /* value_init */
-      NULL,         /* value_free */
-      value_copy_long0,     /* value_copy */
+      value_init_long0,   /* value_init */
+      NULL,     /* value_free */
+      value_copy_long0,   /* value_copy */
       NULL,                     /* value_peek_pointer */
-      "i",          /* collect_format */
-      value_collect_int,    /* collect_value */
-      "p",          /* lcopy_format */
-      value_lcopy_int,      /* lcopy_value */
+      "i",      /* collect_format */
+      value_collect_int,  /* collect_value */
+      "p",      /* lcopy_format */
+      value_lcopy_int,    /* lcopy_value */
     };
     info.value_table = &value_table;
     type = g_type_register_fundamental (G_TYPE_INT, g_intern_static_string ("gint"), &info, &finfo, 0);
@@ -499,14 +499,14 @@ _g_value_types_init (void)
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_long0,     /* value_init */
-      NULL,         /* value_free */
-      value_copy_long0,     /* value_copy */
+      value_init_long0,   /* value_init */
+      NULL,     /* value_free */
+      value_copy_long0,   /* value_copy */
       NULL,                     /* value_peek_pointer */
-      "l",          /* collect_format */
-      value_collect_long,   /* collect_value */
-      "p",          /* lcopy_format */
-      value_lcopy_long,     /* lcopy_value */
+      "l",      /* collect_format */
+      value_collect_long, /* collect_value */
+      "p",      /* lcopy_format */
+      value_lcopy_long,   /* lcopy_value */
     };
     info.value_table = &value_table;
     type = g_type_register_fundamental (G_TYPE_LONG, g_intern_static_string ("glong"), &info, &finfo, 0);
@@ -519,14 +519,14 @@ _g_value_types_init (void)
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_int64,     /* value_init */
-      NULL,         /* value_free */
-      value_copy_int64,     /* value_copy */
+      value_init_int64,   /* value_init */
+      NULL,     /* value_free */
+      value_copy_int64,   /* value_copy */
       NULL,                     /* value_peek_pointer */
-      "q",          /* collect_format */
+      "q",      /* collect_format */
       value_collect_int64,  /* collect_value */
-      "p",          /* lcopy_format */
-      value_lcopy_int64,    /* lcopy_value */
+      "p",      /* lcopy_format */
+      value_lcopy_int64,  /* lcopy_value */
     };
     info.value_table = &value_table;
     type = g_type_register_fundamental (G_TYPE_INT64, g_intern_static_string ("gint64"), &info, &finfo, 0);
@@ -539,14 +539,14 @@ _g_value_types_init (void)
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_float,      /* value_init */
-      NULL,          /* value_free */
-      value_copy_float,      /* value_copy */
+      value_init_float,    /* value_init */
+      NULL,      /* value_free */
+      value_copy_float,    /* value_copy */
       NULL,                      /* value_peek_pointer */
-      "d",           /* collect_format */
+      "d",       /* collect_format */
       value_collect_float,   /* collect_value */
-      "p",           /* lcopy_format */
-      value_lcopy_float,     /* lcopy_value */
+      "p",       /* lcopy_format */
+      value_lcopy_float,   /* lcopy_value */
     };
     info.value_table = &value_table;
     type = g_type_register_fundamental (G_TYPE_FLOAT, g_intern_static_string ("gfloat"), &info, &finfo, 0);
@@ -557,14 +557,14 @@ _g_value_types_init (void)
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_double,    /* value_init */
-      NULL,         /* value_free */
-      value_copy_double,    /* value_copy */
+      value_init_double,  /* value_init */
+      NULL,     /* value_free */
+      value_copy_double,  /* value_copy */
       NULL,                     /* value_peek_pointer */
-      "d",          /* collect_format */
+      "d",      /* collect_format */
       value_collect_double, /* collect_value */
-      "p",          /* lcopy_format */
-      value_lcopy_double,   /* lcopy_value */
+      "p",      /* lcopy_format */
+      value_lcopy_double, /* lcopy_value */
     };
     info.value_table = &value_table;
     type = g_type_register_fundamental (G_TYPE_DOUBLE, g_intern_static_string ("gdouble"), &info, &finfo, 0);
@@ -575,14 +575,14 @@ _g_value_types_init (void)
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_string,    /* value_init */
-      value_free_string,    /* value_free */
-      value_copy_string,    /* value_copy */
+      value_init_string,  /* value_init */
+      value_free_string,  /* value_free */
+      value_copy_string,  /* value_copy */
       value_peek_pointer0,  /* value_peek_pointer */
-      "p",          /* collect_format */
+      "p",      /* collect_format */
       value_collect_string, /* collect_value */
-      "p",          /* lcopy_format */
-      value_lcopy_string,   /* lcopy_value */
+      "p",      /* lcopy_format */
+      value_lcopy_string, /* lcopy_value */
     };
     info.value_table = &value_table;
     type = g_type_register_fundamental (G_TYPE_STRING, g_intern_static_string ("gchararray"), &info, &finfo, 0);
@@ -593,13 +593,13 @@ _g_value_types_init (void)
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_pointer,   /* value_init */
-      NULL,         /* value_free */
-      value_copy_pointer,   /* value_copy */
+      value_init_pointer, /* value_init */
+      NULL,     /* value_free */
+      value_copy_pointer, /* value_copy */
       value_peek_pointer0,  /* value_peek_pointer */
-      "p",          /* collect_format */
-      value_collect_pointer,    /* collect_value */
-      "p",          /* lcopy_format */
+      "p",      /* collect_format */
+      value_collect_pointer,  /* collect_value */
+      "p",      /* lcopy_format */
       value_lcopy_pointer,  /* lcopy_value */
     };
     info.value_table = &value_table;
@@ -611,13 +611,13 @@ _g_value_types_init (void)
    */
   {
     static const GTypeValueTable value_table = {
-      value_init_pointer,   /* value_init */
-      value_free_variant,   /* value_free */
-      value_copy_variant,   /* value_copy */
+      value_init_pointer, /* value_init */
+      value_free_variant, /* value_free */
+      value_copy_variant, /* value_copy */
       value_peek_pointer0,  /* value_peek_pointer */
-      "p",          /* collect_format */
-      value_collect_variant,    /* collect_value */
-      "p",          /* lcopy_format */
+      "p",      /* collect_format */
+      value_collect_variant,  /* collect_value */
+      "p",      /* lcopy_format */
       value_lcopy_variant,  /* lcopy_value */
     };
     info.value_table = &value_table;
@@ -638,7 +638,7 @@ _g_value_types_init (void)
  */
 void
 g_value_set_char (GValue *value,
-          gchar   v_char)
+      gchar   v_char)
 {
   g_return_if_fail (G_VALUE_HOLDS_CHAR (value));
 
@@ -676,7 +676,7 @@ g_value_get_char (const GValue *value)
  */
 void
 g_value_set_schar (GValue *value,
-           gint8   v_char)
+       gint8   v_char)
 {
   g_return_if_fail (G_VALUE_HOLDS_CHAR (value));
 
@@ -709,7 +709,7 @@ g_value_get_schar (const GValue *value)
  */
 void
 g_value_set_uchar (GValue *value,
-           guchar  v_uchar)
+       guchar  v_uchar)
 {
   g_return_if_fail (G_VALUE_HOLDS_UCHAR (value));
 
@@ -741,7 +741,7 @@ g_value_get_uchar (const GValue *value)
  */
 void
 g_value_set_boolean (GValue  *value,
-             gboolean v_boolean)
+         gboolean v_boolean)
 {
   g_return_if_fail (G_VALUE_HOLDS_BOOLEAN (value));
 
@@ -773,7 +773,7 @@ g_value_get_boolean (const GValue *value)
  */
 void
 g_value_set_int (GValue *value,
-         gint    v_int)
+     gint  v_int)
 {
   g_return_if_fail (G_VALUE_HOLDS_INT (value));
 
@@ -805,7 +805,7 @@ g_value_get_int (const GValue *value)
  */
 void
 g_value_set_uint (GValue *value,
-          guint   v_uint)
+      guint   v_uint)
 {
   g_return_if_fail (G_VALUE_HOLDS_UINT (value));
 
@@ -837,7 +837,7 @@ g_value_get_uint (const GValue *value)
  */
 void
 g_value_set_long (GValue *value,
-          glong   v_long)
+      glong   v_long)
 {
   g_return_if_fail (G_VALUE_HOLDS_LONG (value));
 
@@ -869,7 +869,7 @@ g_value_get_long (const GValue *value)
  */
 void
 g_value_set_ulong (GValue *value,
-           gulong  v_ulong)
+       gulong  v_ulong)
 {
   g_return_if_fail (G_VALUE_HOLDS_ULONG (value));
 
@@ -902,7 +902,7 @@ g_value_get_ulong (const GValue *value)
  */
 void
 g_value_set_int64 (GValue *value,
-           gint64  v_int64)
+       gint64  v_int64)
 {
   g_return_if_fail (G_VALUE_HOLDS_INT64 (value));
 
@@ -933,7 +933,7 @@ g_value_get_int64 (const GValue *value)
  */
 void
 g_value_set_uint64 (GValue *value,
-            guint64 v_uint64)
+        guint64 v_uint64)
 {
   g_return_if_fail (G_VALUE_HOLDS_UINT64 (value));
 
@@ -965,7 +965,7 @@ g_value_get_uint64 (const GValue *value)
  */
 void
 g_value_set_float (GValue *value,
-           gfloat  v_float)
+       gfloat  v_float)
 {
   g_return_if_fail (G_VALUE_HOLDS_FLOAT (value));
 
@@ -997,7 +997,7 @@ g_value_get_float (const GValue *value)
  */
 void
 g_value_set_double (GValue *value,
-            gdouble v_double)
+        gdouble v_double)
 {
   g_return_if_fail (G_VALUE_HOLDS_DOUBLE (value));
 
@@ -1029,7 +1029,7 @@ g_value_get_double (const GValue *value)
  */
 void
 g_value_set_string (GValue  *value,
-                    const gchar *v_string)
+        const gchar *v_string)
 {
   gchar *new_val;
 
@@ -1056,7 +1056,7 @@ g_value_set_string (GValue  *value,
  */
 void
 g_value_set_static_string (GValue      *value,
-               const gchar *v_string)
+         const gchar *v_string)
 {
   g_return_if_fail (G_VALUE_HOLDS_STRING (value));
 
@@ -1077,7 +1077,7 @@ g_value_set_static_string (GValue      *value,
  */
 void
 g_value_set_string_take_ownership (GValue *value,
-                   gchar  *v_string)
+           gchar  *v_string)
 {
   g_value_take_string (value, v_string);
 }
@@ -1093,7 +1093,7 @@ g_value_set_string_take_ownership (GValue *value,
  */
 void
 g_value_take_string (GValue *value,
-             gchar  *v_string)
+         gchar  *v_string)
 {
   g_return_if_fail (G_VALUE_HOLDS_STRING (value));
 
@@ -1145,7 +1145,7 @@ g_value_dup_string (const GValue *value)
  */
 void
 g_value_set_pointer (GValue  *value,
-             gpointer v_pointer)
+         gpointer v_pointer)
 {
   g_return_if_fail (G_VALUE_HOLDS_POINTER (value));
 
@@ -1181,7 +1181,7 @@ G_DEFINE_POINTER_TYPE (GType, g_gtype)
  */
 void
 g_value_set_gtype (GValue *value,
-           GType   v_gtype)
+       GType   v_gtype)
 {
   g_return_if_fail (G_VALUE_HOLDS_GTYPE (value));
 
@@ -1343,14 +1343,14 @@ g_strdup_value_contents (const GValue *value)
       src = g_value_get_string (value);
 
       if (!src)
-    contents = g_strdup ("NULL");
+  contents = g_strdup ("NULL");
       else
-    {
-      gchar *s = g_strescape (src, NULL);
+  {
+    gchar *s = g_strescape (src, NULL);
 
-      contents = g_strdup_printf ("\"%s\"", s);
-      g_free (s);
-    }
+    contents = g_strdup_printf ("\"%s\"", s);
+    g_free (s);
+  }
     }
   else if (g_value_type_transformable (G_VALUE_TYPE (value), G_TYPE_STRING))
     {
@@ -1362,11 +1362,11 @@ g_strdup_value_contents (const GValue *value)
       s = g_strescape (g_value_get_string (&tmp_value), NULL);
       g_value_unset (&tmp_value);
       if (G_VALUE_HOLDS_ENUM (value) || G_VALUE_HOLDS_FLAGS (value))
-    contents = g_strdup_printf ("((%s) %s)",
-                    g_type_name (G_VALUE_TYPE (value)),
-                    s);
+  contents = g_strdup_printf ("((%s) %s)",
+            g_type_name (G_VALUE_TYPE (value)),
+            s);
       else
-    contents = g_strdup (s ? s : "NULL");
+  contents = g_strdup (s ? s : "NULL");
       g_free (s);
     }
   else if (g_value_fits_pointer (value))
@@ -1374,11 +1374,11 @@ g_strdup_value_contents (const GValue *value)
       gpointer p = g_value_peek_pointer (value);
 
       if (!p)
-    contents = g_strdup ("NULL");
+  contents = g_strdup ("NULL");
       else if (G_VALUE_HOLDS_OBJECT (value))
-    contents = g_strdup_printf ("((%s*) %p)", G_OBJECT_TYPE_NAME (p), p);
+  contents = g_strdup_printf ("((%s*) %p)", G_OBJECT_TYPE_NAME (p), p);
       else if (G_VALUE_HOLDS_PARAM (value))
-    contents = g_strdup_printf ("((%s*) %p)", G_PARAM_SPEC_TYPE_NAME (p), p);
+  contents = g_strdup_printf ("((%s*) %p)", G_PARAM_SPEC_TYPE_NAME (p), p);
       else if (G_VALUE_HOLDS (value, G_TYPE_STRV))
         {
           GStrv strv = g_value_get_boxed (value);
@@ -1399,11 +1399,11 @@ g_strdup_value_contents (const GValue *value)
           contents = g_string_free (tmp, FALSE);
         }
       else if (G_VALUE_HOLDS_BOXED (value))
-    contents = g_strdup_printf ("((%s*) %p)", g_type_name (G_VALUE_TYPE (value)), p);
+  contents = g_strdup_printf ("((%s*) %p)", g_type_name (G_VALUE_TYPE (value)), p);
       else if (G_VALUE_HOLDS_POINTER (value))
-    contents = g_strdup_printf ("((gpointer) %p)", p);
+  contents = g_strdup_printf ("((gpointer) %p)", p);
       else
-    contents = g_strdup ("???");
+  contents = g_strdup ("???");
     }
   else
     contents = g_strdup ("???");
@@ -1424,16 +1424,16 @@ GType
 g_pointer_type_register_static (const gchar *name)
 {
   const GTypeInfo type_info = {
-    0,          /* class_size */
-    NULL,       /* base_init */
-    NULL,       /* base_finalize */
-    NULL,       /* class_init */
-    NULL,       /* class_finalize */
-    NULL,       /* class_data */
-    0,          /* instance_size */
-    0,          /* n_preallocs */
-    NULL,       /* instance_init */
-    NULL        /* value_table */
+    0,      /* class_size */
+    NULL,   /* base_init */
+    NULL,   /* base_finalize */
+    NULL,   /* class_init */
+    NULL,   /* class_finalize */
+    NULL,   /* class_data */
+    0,      /* instance_size */
+    0,      /* n_preallocs */
+    NULL,   /* instance_init */
+    NULL    /* value_table */
   };
   GType type;
 
